#ifndef BASEDEF_H
#define BASEDEF_H

#define BOOST_DISABLE_ASSERTS true

#include "RcppArmadillo.h"
#include <bigmemory/MatrixAccessor.hpp>
#include <boost/function.hpp>
#include <boost/math/tools/roots.hpp>
#include <boost/math/tools/tuple.hpp>
#include <math.h>
#include <stdlib.h>
#include <string>
#include <vector>
#include <algorithm>
#include <random>

using namespace arma;

#endif
